@@ -1,13 +1,15 @@
 from __future__ import absolute_import
 
-import os
+from ._version import __version__, __version_info__
+
+import os, sys
 
 import lensfunpy._lensfun
 globals().update(lensfunpy._lensfun.__dict__)
 
-# for Windows we wrap the Database constructor to load the bundled database files
+# for Windows and Mac we wrap the Database constructor to load the bundled database files
 # as lensfun wouldn't find any in the standard search locations like on Linux
-if os.name == 'nt':
+if os.name == 'nt' or sys.platform == 'darwin':
     _Database = Database
     del Database
     
@@ -18,10 +20,10 @@ if os.name == 'nt':
     _xml_glob = os.path.join(_ROOT, 'db_files', '*.xml')
     
     @wraps(_Database)
-    def Database(filenames=None, xml=None, loadAll=True):
-        if loadAll:
-            if not filenames:
-                filenames = []
-            filenames.extend(glob.glob(_xml_glob))
-        return _Database(filenames, xml, loadAll)
+    def Database(paths=None, xml=None, load_common=True):
+        if load_common:
+            if not paths:
+                paths = []
+            paths.extend(glob.glob(_xml_glob))
+        return _Database(paths, xml, load_common)
     
\ No newline at end of file
